Index: src/isolate.cc |
diff --git a/src/isolate.cc b/src/isolate.cc |
index f8eebee45740023450c3330d9c5d00f3a3bc8490..c55e00eefa54897c10c4e9fc1f1d3aefaa6bc205 100644 |
--- a/src/isolate.cc |
+++ b/src/isolate.cc |
@@ -358,7 +358,7 @@ |
// Determines whether the given stack frame should be displayed in a stack |
// trace. |
bool IsVisibleInStackTrace(JSFunction* fun) { |
- return ShouldIncludeFrame(fun) && IsNotHidden(fun) && |
+ return ShouldIncludeFrame(fun) && IsNotInNativeScript(fun) && |
IsInSameSecurityContext(fun); |
} |
@@ -386,12 +386,12 @@ |
return false; |
} |
- bool IsNotHidden(JSFunction* fun) { |
- // Functions defined not in user scripts are not visible unless directly |
+ bool IsNotInNativeScript(JSFunction* fun) { |
+ // Functions defined in native scripts are not visible unless directly |
// exposed, in which case the native flag is set. |
// The --builtins-in-stack-traces command line flag allows including |
// internal call sites in the stack trace for debugging purposes. |
- if (!FLAG_builtins_in_stack_traces && !fun->shared()->IsUserJavaScript()) { |
+ if (!FLAG_builtins_in_stack_traces && fun->shared()->IsBuiltin()) { |
return fun->shared()->native(); |
} |
return true; |